
"use strict";

/**
 * @version 1.0.0
 * 
 * Starts the cookie question.
 * 
 * @returns {undefined}
 */
function cookieQuestionStart() {
    /**
     * Adjust the pure default theme name to use.
     * 
     * Hint: The pure theme name may only consist of the letters a..z and A..Z
     * and the underscore ("_"), The complete theme name must be:
     * 
     * CookieQuestionTheme_NAME-OF-THEME-TO-USE.js
     */
    var themeToUse = "MinimalSmart";

    var cookieQuestionDirUrlSlash = "";
    var overrideYesUrl = "";
    var overrideNoUrl = "";
    var overrideCookieName = "";
    var dynLoaderScriptElement = document.getElementById("cookieQuestionIncludeDynLoader");
    if (dynLoaderScriptElement) {
        var overrideTheme = dynLoaderScriptElement.getAttribute("data-theme");
        if((typeof(overrideTheme) === "string") && overrideTheme) {
            themeToUse = overrideTheme.replace(/[^\w]/g, "");
        }
        var cookieQuestionDirUrlSlashTmp = dynLoaderScriptElement.getAttribute("data-cqDirUrlS");
        if((typeof(cookieQuestionDirUrlSlashTmp) === "string")) {
            cookieQuestionDirUrlSlash = cookieQuestionDirUrlSlashTmp.replace(/[^\w-.~:/+%]/g, "");
        }
        var yesUrlTmp = dynLoaderScriptElement.getAttribute("data-yesUrl");
        if((typeof(yesUrlTmp) === "string")) {
            overrideYesUrl = yesUrlTmp.replace(/[^\w-.~:/+%]/g, "");
        }
        var noUrlTmp = dynLoaderScriptElement.getAttribute("data-noUrl");
        if((typeof(noUrlTmp) === "string")) {
            overrideNoUrl = noUrlTmp.replace(/[^\w-.~:/+%]/g, "");
        }
        var cookieNameTmp = dynLoaderScriptElement.getAttribute("data-cookieName");
        if((typeof(cookieNameTmp) === "string")) {
            overrideCookieName = cookieNameTmp.replace(/('|")/g, "");
        }
    }
    window.setTimeout(CookieQuestionDynLoader.loadScriptsHeadEndReverse, 10,
        function () {
            new CookieQuestion(themeToUse, cookieQuestionDirUrlSlash, overrideYesUrl, overrideNoUrl, overrideCookieName);
        },
        [
            cookieQuestionDirUrlSlash + "themes/CookieQuestionTheme_" + themeToUse + ".js",
            cookieQuestionDirUrlSlash + "lib/CookieQuestionStyleElement.js",
            cookieQuestionDirUrlSlash + "CookieQuestion.js",
            cookieQuestionDirUrlSlash + "themes/CookieQuestionTheme.js",
            cookieQuestionDirUrlSlash + "lib/CookieQuestionBlendHelper.js",
            cookieQuestionDirUrlSlash + "lib/CookieQuestionCookieHelper.js",
            cookieQuestionDirUrlSlash + "lib/CookieQuestionIp4Address.js"
        ]
        );
}

/**
 * Tests for path to cookieQuestion, loads the lib-loader for cookie question.
 * 
 * @returns {undefined}
 */
function cookieQuestionBootstrap() {
    var includingScriptElement;
    var docScripts = document.getElementsByTagName("script");
    for(var i = docScripts.length - 1; i >= 0; i--) {
        var scriptx = docScripts[i];
        var scriptxSrc = scriptx.getAttribute("src");
        if((typeof(scriptxSrc) === "string") && (scriptxSrc.substr(scriptxSrc.length - 25) === "/cookieQuestionStarter.js")) {
            includingScriptElement = scriptx;
            break;
        }
    }
    var thisUrl = includingScriptElement.getAttribute("src");
    var thisPos = thisUrl.lastIndexOf("cookieQuestion");
    var cookieQuestionDirUrlSlash = thisUrl.substr(0, thisPos);
    var overrideTheme = includingScriptElement.getAttribute("data-theme");
    if((typeof(overrideTheme) !== "string")) {
        overrideTheme = "";
    }
    var overrideYesUrl = includingScriptElement.getAttribute("data-yesUrl");
    if((typeof(overrideYesUrl) !== "string")) {
        overrideYesUrl = "";
    }
    var overrideNoUrl = includingScriptElement.getAttribute("data-noUrl");
    if((typeof(overrideNoUrl) !== "string")) {
        overrideNoUrl = "";
    }
    var overrideCookieName = includingScriptElement.getAttribute("data-cookieName");
    if((typeof(overrideCookieName) !== "string")) {
        overrideCookieName = "";
    }
    var loaderScript = document.createElement("script");
    loaderScript.src = cookieQuestionDirUrlSlash + "lib/CookieQuestionDynLoader.js";
    loaderScript.charset = "utf8";
    loaderScript.id = "cookieQuestionIncludeDynLoader";
    loaderScript.onload = cookieQuestionStart.bind(this);
    loaderScript.setAttribute("data-cqDirUrlS", cookieQuestionDirUrlSlash);
    loaderScript.setAttribute("data-theme", overrideTheme);
    loaderScript.setAttribute("data-yesUrl", overrideYesUrl);
    loaderScript.setAttribute("data-noUrl", overrideNoUrl);
    loaderScript.setAttribute("data-cookieName", overrideCookieName);
    document.getElementsByTagName("head")[0].appendChild(loaderScript);
}

/* starting point */
cookieQuestionBootstrap();
