
"use strict";
//import * as CookieQuestionStyleElement from "CookieQuestionStyleElement";

/**
 * @requires CookieQuestionStyleElement.js
 * @version 1.0.0
 */

/**
 * Theme-individual data and functions.
 * 
 * @type CookieQuestionTheme_Shy
 */
class CookieQuestionTheme_Shy extends CookieQuestionTheme {
    constructor(cookieQuestionDirUrlS, overrideYesUrl = "", overrideNoUrl = "", overrideCookieName = "") {
        super(cookieQuestionDirUrlS, overrideYesUrl, overrideNoUrl, overrideCookieName);
        this.setup(this.displayQuestion.bind(this),
            this.removeQuestion.bind(this),
            this.goContent.bind(this),
            this.goNoCookieContent.bind(this),
            this.setLang.bind(this));
        // empty if cookie question is on content page
        this.locationCookieContinue = "";
        // empty to go history back or about_blank
        this.locationNoCookies = "";
        this.css = {
            "cookieQuestionForegroundLayer": [
                "-moz-border-radius:15px",
                "-moz-box-shadow:#06083B 8px 8px 8px",
                "-webkit-border-radius:15px",
                "-webkit-box-shadow:#06083B 8px 8px 8px",
                "background-color:rgba(127,127,109,0.97)",
                "border-radius:15px",
                "border-width:8px",
                "box-shadow:#06083B 8px 8px 8px",
                "box-sizing:border-box",
                "left:50%",
                "margin:0 0 0 -38%",
                "overflow-x:auto",
                "padding:10px",
                "position:fixed",
                "top:1em",
                "width:76%",
                "z-index:99999"
            ],
            "cookieQuestionMessageLayer": [
                "background-color:transparent",
                "border:0 none",
                "box-sizing:border-box",
                "color:white",
                "font-size:14px",
                "font-weight:normal",
                "line-height:18px",
                "margin:0 auto 0.5em auto",
                "min-width:300px",
                "overflow-style:marquee",
                "overflow-wrap:break-word",
                "overflow-x:hidden",
                "overflow-y:auto",
                "padding:0.5em 1em",
                "text-align:left",
                "text-shadow:1px 1px black",
                "width:100%",
                "word-break:keep-all",
                "word-wrap:normal"
            ],
            "cookieQuestionAnswerLayer": [
                "background-color:transparent",
                "border:0 none",
                "box-sizing:border-box",
                "color:black",
                "display:table-cell",
                "font-size:13px",
                "font-weight:800",
                "line-height:16px",
                "margin:0 auto",
                "max-width:370px",
                "min-width:310px",
                "outline-style:none",
                "overflow-style:marquee",
                "overflow-wrap:break-word",
                "overflow-x:hidden",
                "overflow-y:hidden",
                "padding:0 1em",
                "position:relative",
                "text-align:center",
                "vertical-align:middle"
            ],
            "cookieQuestionTriggerNo": [
                "background-color:rgba(255,0,0,0.5)",
                "border:0 none",
                "box-sizing:border-box",
                "cursor:pointer",
                "display:inline-block",
                "float:left",
                "margin:0.5em 0 0.5em 2px",
                "padding:0",
                "position:relative",
                "text-align:center",
                "vertical-align:middle",
                "width:90px"
            ],
            "cookieQuestionTriggerOnce": [
                "background-color:rgba(255,255,0,0.5)",
                "border:0 none",
                "box-sizing:border-box",
                "cursor:pointer",
                "display:inline-block",
                "left:50%",
                "margin:0.5em 0 0.5em -45px",
                "padding:0",
                "position:absolute",
                "text-align:center",
                "vertical-align:middle",
                "width:90px"
            ],
            "cookieQuestionTriggerYes": [
                "background-color:rgba(0,255,0,0.5)",
                "border:0 none",
                "box-sizing:border-box",
                "cursor:pointer",
                "display:inline-block",
                "float:right",
                "margin:0.5em 0 0.5em 0",
                "padding:0",
                "position:relative",
                "text-align:center",
                "vertical-align:middle",
                "width:90px"
            ]
        };
        this.styleRules = [
            ".cookieQuestionAnswer:focus, .cookieQuestionAnswer:hover {"
                +"outline-color:aqua;"
                +"outline-style:solid;"
                +"outline-width:1px;"
            +"}"
        ];
        this.langData = {
            "en": {
                "msg": [
                    "This website ist available for free. ",
                    "Advertisement originated by Google (AdSense) is presented, cookies are used. ",
                    "Additionally this site uses own cookies which are only used to "
                        + "support functionality and are in no way used for your identification nor to track you. ",
                    "According to data protecting laws of the EU you need to accept the use of the mentioned cookies. ",
                    "Do you accept the use of cookies?"
                ],
                "no": "No",
                "once": "Once",
                "yes": "Yes"
            },
            "de": {
                "msg": [
                    "Diese Website ist kostenfrei verfügbar. ",
                    "Von Google bereit gestellte Werbung (AdSense) ist integriert "
                        + "und verwendet Cookies. ",
                    "Diese Site verwendet auch eigene Cookies, die "
                        + "weder zu Ihrer Identifikation noch zur Nachverfolgung, "
                        + "sondern zur Funktionalität dieser Site verwendet werden. ",
                    "Gemäß Datenschutzrichtlinie der EU müssen Sie der Verwendung "
                        + "der genannten Cookies zustimmen. ",
                    "Akzeptieren Sie die Verwendung von Cookies?"
                ],
                "no": "Nein",
                "once": "Einmalig",
                "yes": "Ja"
            }
        };
        this.lang = "en";
        this.rootLayer;
        this.cookieElemNo;
        this.cookieElemOnce;
        this.cookieElemYes;
    }

    /**
     * Sets the language to use, defaults to "en".
     * 
     * @param {string} langCode The 2-letter lowercase language code like e.g. 
     * "en".
     * @returns {undefined}
     */
    setLang(langCode = "") {
        this.lang = this.langData[langCode] ? langCode : "en";
    }

    /**
     * Gets language specific versions of data, defaults to "en".
     * 
     * @param {} lang The 2-letter lowercase language code like e.g. 
     * "en".
     * @param {string} msgId The code for the data to return.
     * @returns {string} Language specifc data.
     */
    getLangMsg(lang, msgId) {
        var msg = "";
        if (this.langData[lang] && this.langData[lang][msgId]) {
            msg = this.langData[lang][msgId];
        }
        return msg;
    }

    /**
     * Gets language specific versions of data.
     * 
     * @param {string} msgId The code for the data to return.
     * @returns {string} Language specifc data.
     */
    getMsg(msgId) {
        var msg = this.getLangMsg(this.lang, msgId);
        if (!msg) {
            for (var l in this.langData) {
                if (this.langData[l].msgId) {
                    msg = this.langData[l].msgId;
                    break;
                }
            }
        }
        return msg;
    }

    /**
     * Displays the cookie question.
     * 
     * Relies on set this.bodyElem in super class CookieQuestionTheme
     * 
     * @returns {undefined}
     */
    displayQuestion() {
        
        CookieQuestionStyleElement.createStyleSheet(this.styleRules);
              
        this.rootLayer = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionForegroundLayer"], "div", "cookieQuestionForegroundLayer_id");
        var cookieMessageLayer = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionMessageLayer"], "div", "cookieQuestionMessageLayer_id");

        CookieQuestionStyleElement.appendText(this.getMsg("msg"), cookieMessageLayer);

        var cookieAnswerLayer = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionAnswerLayer"], "div", "cookieQuestionAnswerLayer_id");

        this.cookieElemNo = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerNo"], "span", "cookieQuestionTriggerNo_id");
        CookieQuestionStyleElement.appendText([this.getMsg("no")], this.cookieElemNo);
        this.cookieElemNo.classList.add("cookieQuestionAnswer");
        this.cookieElemNo.onclick = this.cookiesNo.bind(this);

        this.cookieElemOnce = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerOnce"], "span", "cookieQuestionTriggerOnce_id");
        CookieQuestionStyleElement.appendText([this.getMsg("once")], this.cookieElemOnce);
        this.cookieElemOnce.classList.add("cookieQuestionAnswer");
        this.cookieElemOnce.onclick = this.cookiesOnce.bind(this);

        this.cookieElemYes = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerYes"], "span", "cookieQuestionTriggerYes_id");
        CookieQuestionStyleElement.appendText([this.getMsg("yes")], this.cookieElemYes);
        this.cookieElemYes.classList.add("cookieQuestionAnswer");
        this.cookieElemYes.onclick = this.cookiesYes.bind(this);

        cookieAnswerLayer.appendChild(this.cookieElemNo);
        cookieAnswerLayer.appendChild(this.cookieElemOnce);
        cookieAnswerLayer.appendChild(this.cookieElemYes);

        this.rootLayer.appendChild(cookieMessageLayer);
        this.rootLayer.appendChild(cookieAnswerLayer);
        var bodyChildNodes = this.bodyElem.childNodes;
        if (bodyChildNodes === null) {
            this.bodyElem.appendChild(this.rootLayer);
        }
        else {
            this.bodyElem.insertBefore(this.rootLayer, bodyChildNodes[0]);
        }

        this.cookieElemNo.setAttribute("tabindex", "0");
        this.cookieElemNo.setAttribute("nav-index", "0");
        this.cookieElemOnce.setAttribute("tabindex", "0");
        this.cookieElemOnce.setAttribute("nav-index", "0");
        this.cookieElemYes.setAttribute("tabindex", "0");
        this.cookieElemYes.setAttribute("nav-index", "0");
        
        this.cookieElemNo.addEventListener("keydown", this, true);
        this.cookieElemOnce.addEventListener("keydown", this, true);
        this.cookieElemYes.addEventListener("keydown", this, true);
        
        this.cookieElemYes.focus();
    }

    handleEvent(evt) {
        if ((evt.type === "keydown") && ((evt.key === "Enter") || (evt.key === " ") || (evt.key === "Spacebar"))) {
            if (document.activeElement === this.cookieElemNo) {
                this.cookiesNo();
            }
            else if (document.activeElement === this.cookieElemOnce) {
                this.cookiesOnce();
            }
            else if (document.activeElement === this.cookieElemYes) {
                this.cookiesYes();
            }
        }
    }

    removeTriggerListener() {
        this.cookieElemNo.removeEventListener("keydown", this);
        this.cookieElemOnce.removeEventListener("keydown", this);
        this.cookieElemYes.removeEventListener("keydown", this);
    }

    /**
     * Removes the cookie question from screnn.
     * 
     * Relies on set this.bodyElem in super class CookieQuestionTheme
     * 
     * @returns {undefined}
     */
    removeQuestion() {
        this.removeTriggerListener();
        try {
            this.bodyElem.removeChild(this.rootLayer);
            this.rootLayer = null;
            this.cookieElemNo = this.cookieElemOnce = this.cookieElemYes = null;
        }
        catch (err) {
        }
    }

    /**
     * Specifies the action to display a web page after cookies have been 
     * rejected (no).
     * 
     * @returns {undefined}
     */
    goNoCookieContent() {
        if (this.effectiveNoUrl()) {
            window.top.location.href = this.effectiveNoUrl();
        }
        else if (history.length > 1) {
            window.history.back();
        }
        else {
            window.top.location.href = "about:blank";
        }
    }

    /**
     * Specifies the action to display a web page after cookies have been 
     * accepted (once or yes).
     * 
     * @returns {undefined}
     */
    goContent() {
        if (this.effectiveYesUrl()) {
            window.top.location.href = this.effectiveYesUrl();
        }
        /* else stay on current page */
    }
}
