
"use strict";
//import * as CookieQuestionStyleElement from "CookieQuestionStyleElement";
//import * as CookieQuestionBlendHelper from "CookieQuestionBlendHelper";

/**
 * @requires CookieQuestionStyleElement.js
 * @requires CookieQuestionBlendHelper.js
 * @version 1.0.0
 */

/**
 * Theme-individual data and functions.
 * 
 * @type CookieQuestionTheme_Minimal
 */
class CookieQuestionTheme_Minimal extends CookieQuestionTheme {
    constructor(cookieQuestionDirUrlS, overrideYesUrl = "", overrideNoUrl = "", overrideCookieName = "") {
        super(cookieQuestionDirUrlS, overrideYesUrl, overrideNoUrl, overrideCookieName);
        this.setup(this.displayQuestion.bind(this),
            this.removeQuestion.bind(this),
            this.goContent.bind(this),
            new function() {},
            this.setLang.bind(this));
        this.resourcesDir = this.safeCookieQuestionDirUrlS+"cookieQuestion/themes/resources/";
        // empty if cookie question is on content page
        this.locationCookieContinue = "";
        // empty to go history back or about:blank
        // unused in this theme: this.locationNoCookies = "";
        this.css = {
            "cookieQuestionLayer": [
                "background-color:#282eb3",
                "border:0 none",
                "bottom:0",
                "box-sizing:border-box",
                "left:0",
                "margin:0",
                "opacity:0.89",
                "padding:13px",
                "position:fixed",
                "width:100%",
                "z-index:99999"
            ],
            "cookieQuestionMessageLayer": [
                "background-color:transparent",
                "border:0 none",
                "box-sizing:border-box",
                "color:white",
                "font-size:16px",
                "font-weight:normal",
                "margin:0 auto",
                "overflow-wrap:break-word",
                "overflow-x:visible",
                "overflow-y:visible",
                "padding:0",
                "padding:0",
                "text-align:center",
                "text-shadow:1px 1px black",
                "vertical-align:middle",
                "word-break:keep-all",
                "word-wrap:normal"
            ],
            "cookieQuestionTriggerYes": [
                "background-color:green",
                "border:0 none",
                "box-sizing:border-box",
                "color:black",
                "cursor:pointer",
                "display:inline-block",
                "font-size:16px",
                "letter-spacing:2px",
                "line-height:20px",
                "margin:0 2em;",
                "padding:0;",
                "position:relative",
                "width:80px"
            ]
        };
        this.styleRules = [
                 "#cookieQuestionTriggerYes_id:focus, #cookieQuestionTriggerYes_id:hover {"
                +"outline-color:yellow;"
                +"outline-style:dotted;"
                +"outline-width:1px;"
                +"}"
            ];
        this.langData = {
            "en": {
                "msg": [
                    "This site uses cookies and Google AdSense, do you accept?"
                ],
                "yes": "Yes"
            },
            "de": {
                "msg": [
                    "Diese Site verwendet Cookies und Google AdSense, akzeptieren Sie deren Benutzung?"
                ],
                "yes": "Ja"
            }
        };
        this.lang = "en";
        this.rootLayer;
    }
    
    /**
     * Sets the language to use, defaults to "en".
     * 
     * @param {string} langCode The 2-letter lowercase language code like e.g. 
     * "en".
     * @returns {undefined}
     */
    setLang(langCode = "") {
        this.lang = this.langData[langCode] ? langCode : "en";
    }

    /**
     * Gets language specific versions of data, defaults to "en".
     * 
     * @param {} lang The 2-letter lowercase language code like e.g. 
     * "en".
     * @param {string} msgId The code for the data to return.
     * @returns {string} Language specifc data.
     */
    getLangMsg(lang, msgId) {
        var msg = "";
        if (this.langData[lang] && this.langData[lang][msgId]) {
            msg = this.langData[lang][msgId];
        }
        return msg;
    }

    /**
     * Gets language specific versions of data.
     * 
     * @param {string} msgId The code for the data to return.
     * @returns {string} Language specifc data.
     */
    getMsg(msgId) {
        var msg = this.getLangMsg(this.lang, msgId);
        if (!msg) {
            for (var l in this.langData) {
                if (this.langData[l].msgId) {
                    msg = this.langData[l].msgId;
                    break;
                }
            }
        }
        return msg;
    }

    /**
     * Displays the cookie question.
     * 
     * Relies on set this.bodyElem in super class CookieQuestionTheme
     * 
     * @returns {undefined}
     */
    displayQuestion() {
        this.rootLayer = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionLayer"], "div", "cookieQuestionLayer_id");

        
        var cookieMessageLayer = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionMessageLayer"], "div", "cookieQuestionMessageLayer_id");

        CookieQuestionStyleElement.appendText(this.getMsg("msg"), cookieMessageLayer);

        var cookieElemYes = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerYes"], "button", "cookieQuestionTriggerYes_id");
        CookieQuestionStyleElement.appendText([this.getMsg("yes")], cookieElemYes);
        cookieElemYes.classList.add("cookieQuestionYes");
        cookieElemYes.onclick = this.cookiesYes.bind(this);
        cookieMessageLayer.appendChild(cookieElemYes);

        this.rootLayer.appendChild(cookieMessageLayer);
        var bodyChildNodes = this.bodyElem.childNodes;
        if (bodyChildNodes === null) {
            this.bodyElem.appendChild(this.rootLayer);
        }
        else {
            this.bodyElem.insertBefore(this.rootLayer, bodyChildNodes[0]);
        }

        CookieQuestionStyleElement.createStyleSheet(this.styleRules);
        cookieElemYes.focus();
    }

    /**
     * Blends out the cookie question, then calls deleteQuestion.
     * 
     * Relies on set this.bodyElem in super class CookieQuestionTheme
     * 
     * @returns {undefined}
     */
    removeQuestion() {
        CookieQuestionBlendHelper.blend(this.rootLayer, 0, 1, 20, this.deleteQuestion.bind(this));
    }

    /**
     * Removes the cookie question from screnn.
     * 
     * Relies on set this.bodyElem in super class CookieQuestionTheme
     * 
     * @returns {undefined}
     */
    deleteQuestion() {
        try {
            this.bodyElem.removeChild(this.rootLayer);
            this.rootLayer = null;
        }
        catch (err) {
        }
    }

    /**
     * Specifies the action to display a web page after cookies have been 
     * accepted (once or yes).
     * 
     * @returns {undefined}
     */
    goContent() {
        if (this.effectiveYesUrl()) {
            window.top.location.href = this.effectiveYesUrl();
        }
        /* else stay on current page */
    }
}
