
"use strict";
//import * as CookieQuestionStyleElement from "CookieQuestionStyleElement";
//import * as CookieQuestionBlendHelper from "CookieQuestionBlendHelper";

/**
 * @requires CookieQuestionStyleElement.js
 * @requires CookieQuestionBlendHelper.js
 * @version 1.0.0
 */

/**
 * Theme-individual data and functions.
 * 
 * @type CookieQuestionTheme_Minimal
 */
class CookieQuestionTheme_MinimalSmartG extends CookieQuestionTheme {
    constructor(cookieQuestionDirUrlS, overrideYesUrl = "", overrideNoUrl = "", overrideCookieName = "") {
        super(cookieQuestionDirUrlS, overrideYesUrl, overrideNoUrl, overrideCookieName);
        this.setup(this.displayQuestion.bind(this),
            this.removeQuestion.bind(this),
            this.goContent.bind(this),
            new function() {},
            this.setLang.bind(this));
        this.resourcesDir = this.safeCookieQuestionDirUrlS+"cookieQuestion/themes/resources/";
        // empty if cookie question is on content page
        this.locationCookieContinue = "";
        // empty to go history back or about:blank
        // unused in this theme: this.locationNoCookies = "";
        this.css = {
            "cookieQuestionLayer": [
                "background-color:#2023d9",
                "border:0 none",
                "bottom:0",
                "box-sizing:border-box",
                "left:0",
                "margin:0",
                "opacity:0.89",
                "padding:0",
                "position:fixed",
                "width:100%",
                "z-index:99999"
            ],
            "cookieQuestionMessageLayer": [
                "background-color:transparent",
                "border:0 none",
                "bottom:0",
                "box-sizing:border-box",                
                "color:white",
                "font-size:8mm",
                "font-weight:normal",
                "left:0",
                "line-height:12mm",
                "margin:0 auto",                
                "overflow-wrap:break-word",
                "overflow-x:visible",
                "overflow-y:visible",                
                "padding:8mm 1em",
                "text-align:center",
                "text-shadow:1px 1px black",
                "vertical-align:middle",
                "width:100%",
                "word-break:keep-all",
                "word-wrap:normal"
            ],
            "cookieQuestionTriggerYes": [
                "-moz-border-radius:7px",
                "-webkit-border-radius:7px",
                "background-color:#f9b52a",
                "border-radius:7px",
                "border:0 none",
                "box-sizing:border-box",
                "color:#140488",
                "cursor:pointer",
                "display:inline-block",
                "font-size:8mm",
                "letter-spacing:2px",
                "line-height:12mm",
                "margin:0 1em",
                "outline-color:transparent",                    
                "outline-style:none",                    
                "outline-width:0",                    
                "padding:0",
                "position:relative",
                "width:80px"
            ],
            "cookieQuestionMsgLink": [
                "color:white",
                "outline:0"
            ]
        };
        this.langData = {
            "en": {
                "msg": [
                    "This site uses cookies and ",
                    ">>>http://www.google.de/policies/privacy/partners/<<<Google AdSense",
                    ", do you accept?"
                ],
                "yes": "Yes"
            },
            "de": {
                "msg": [
                    "Diese Site verwendet Cookies und ",
                    ">>>http://www.google.de/policies/privacy/partners/<<<Google AdSense",
                    ", akzeptieren Sie deren Benutzung?"
                ],
                "yes": "Ja"
            }
        };
        this.lang = "en";
        this.rootLayer;
    }

    /**
     * Sets the language to use, defaults to "en".
     * 
     * @param {string} langCode The 2-letter lowercase language code like e.g. 
     * "en".
     * @returns {undefined}
     */
    setLang(langCode = "") {
        this.lang = this.langData[langCode] ? langCode : "en";
    }

    /**
     * Gets language specific versions of data, defaults to "en".
     * 
     * @param {} lang The 2-letter lowercase language code like e.g. 
     * "en".
     * @param {string} msgId The code for the data to return.
     * @returns {string} Language specifc data.
     */
    getLangMsg(lang, msgId) {
        var msg = "";
        if (this.langData[lang] && this.langData[lang][msgId]) {
            msg = this.langData[lang][msgId];
        }
        return msg;
    }

    /**
     * Gets language specific versions of data.
     * 
     * @param {string} msgId The code for the data to return.
     * @returns {string} Language specifc data.
     */
    getMsg(msgId) {
        var msg = this.getLangMsg(this.lang, msgId);
        if (!msg) {
            for (var l in this.langData) {
                if (this.langData[l].msgId) {
                    msg = this.langData[l].msgId;
                    break;
                }
            }
        }
        return msg;
    }

    /**
     * Displays the cookie question.
     * 
     * Relies on set this.bodyElem in super class CookieQuestionTheme
     * 
     * @returns {undefined}
     */
    displayQuestion() {
        // An alternative, overridable way to set text, not usuable for frameset/frames
        /* CookieQuestionStyleElement.createStyleSheet([
            "#cookieQuestionMessageLayer_id:before {content:'"+this.getMsg("msg")+"';}",
            "#cookieQuestionTriggerYes_id:before {content:'"+this.getMsg("yes")+"';}"
        ]);*/

        this.rootLayer = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionLayer"], "div", "cookieQuestionLayer_id");
        var cookieMessageLayer = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionMessageLayer"], "div", "cookieQuestionMessageLayer_id");
        CookieQuestionStyleElement.appendText(this.getMsg("msg"), cookieMessageLayer);
        
        var cookieElemYes = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerYes"], "button", "cookieQuestionTriggerYes_id");
        CookieQuestionStyleElement.appendText([this.getMsg("yes")], cookieElemYes);
        cookieElemYes.onclick = this.cookiesYes.bind(this);

        cookieMessageLayer.appendChild(cookieElemYes);
        this.rootLayer.appendChild(cookieMessageLayer);
        var bodyChildNodes = this.bodyElem.childNodes;
        if (bodyChildNodes === null) {
            this.bodyElem.appendChild(this.rootLayer);
        }
        else {
            this.bodyElem.insertBefore(this.rootLayer, bodyChildNodes[0]);
        }
        CookieQuestionStyleElement.applyCss(this.css["cookieQuestionMsgLink"], "#cookieQuestionMsgLink_1_id");
        cookieElemYes.focus();
    }
    
    /**
     * Blends out the cookie question, then calls deleteQuestion.
     * 
     * Relies on set this.bodyElem in super class CookieQuestionTheme
     * 
     * @returns {undefined}
     */
    removeQuestion() {
        CookieQuestionBlendHelper.blend(this.rootLayer, 0, 1, 20, this.deleteQuestion.bind(this));
    }

    /**
     * Removes the cookie question from screnn.
     * 
     * Relies on set this.bodyElem in super class CookieQuestionTheme
     * 
     * @returns {undefined}
     */
    deleteQuestion() {
        try {
            this.bodyElem.removeChild(this.rootLayer);
            this.rootLayer = null;
        }
        catch (err) {
        }
    }

    /**
     * Specifies the action to display a web page after cookies have been 
     * accepted (once or yes).
     * 
     * @returns {undefined}
     */
    goContent() {
        if (this.effectiveYesUrl()) {
            window.top.location.href = this.effectiveYesUrl();
        }
        /* else stay on current page */
    }
}
