
"use strict";
//import * as CookieQuestionStyleElement from "CookieQuestionStyleElement";

/**
 * @requires CookieQuestionStyleElement.js
 * @version 1.0.0
 */

/**
 * Theme-individual data and functions.
 * 
 * @type CookieQuestionTheme_ShySmart
 */
class CookieQuestionTheme_ShySmart extends CookieQuestionTheme {
    constructor(cookieQuestionDirUrlS, overrideYesUrl = "", overrideNoUrl = "", overrideCookieName = "") {
        super(cookieQuestionDirUrlS, overrideYesUrl, overrideNoUrl, overrideCookieName);
        this.setup(this.displayQuestion.bind(this),
            this.removeQuestion.bind(this),
            this.goContent.bind(this),
            this.goNoCookieContent.bind(this),
            this.setLang.bind(this));
        // empty if cookie question is on content page
        this.locationCookieContinue = "";
        // empty to go history back or about_blank
        this.locationNoCookies = "";
        this.css = {
            "cookieQuestionForegroundLayer": [
                "-moz-border-radius:15px",
                "-moz-box-shadow:#06083B 8px 8px 8px",
                "-webkit-border-radius:15px",
                "-webkit-box-shadow:#06083B 8px 8px 8px",
                "background-color:rgba(88,57,15,0.85)",
                "border-radius:15px",
                "border:3px solid #220AC2",
                "box-shadow:#06083B 8px 8px 8px",
                "box-sizing:border-box",
                "left:1em",
                "margin:0",
                "max-width:600px",
                "min-width:200px",
                "padding:10px",
                "position:fixed",
                "top:1em",
                "width:600px",
                "z-index:99999"
            ],
            "cookieQuestionMessageLayer": [
                "background-color:transparent",
                "border:0 none",
                "box-sizing:border-box",
                "color:white",
                "font-size:8mm",
                "font-weight:normal",
                "line-height:12mm",
                "margin:0 auto",
                "overflow-style:marquee",
                "overflow-wrap:break-word",
                "overflow-x:hidden",
                "overflow-y:auto",
                "padding:0.5em 1em",
                "text-align:left",
                "text-shadow:1px 1px black",
                "width:95%",
                "word-break:keep-all",
                "word-wrap:normal"
            ],
            "cookieQuestionAnswerLayer": [
                "background-color:transparent",
                "border:0 none",
                "box-sizing:border-box",
                "color:black",
                "margin:0 auto",
                "overflow-style:marquee",
                "overflow-wrap:break-word",
                "overflow-x:hidden",
                "overflow-y:hidden",
                "padding:0",
                "text-align:center",
                "vertical-align:middle"
            ],
            "cookieQuestionTriggerCommon": [
                "-moz-box-shadow:0px 2px 1px rgba(50, 50, 50, 0.75)",
                "-webkit-box-shadow:0px 2px 1px rgba(50, 50, 50, 0.75)",
                "border-color:#88F",
                "border-style:ridge",
                "border-width:2px",
                "box-shadow:0px 2px 1px rgba(50, 50, 50, 0.75)",
                "box-sizing:border-box",
                "color:black",
                "cursor:pointer",
                "display:block",
                "font-size:8mm",
                "font-weight:normal",
                "height:15mm",
                "letter-spacing:2px",
                "line-height:12mm",
                "margin:1em auto",
                "outline-style:none 0",
                "padding:0",
                "position:relative",
                "text-shadow:1px 1px 1px lightgrey",
                "vertical-align:middle",
                "width:60mm"
            ],
            "cookieQuestionTriggerNo": [
                "background:#ff6b6b",
                "background:-moz-linear-gradient(top,  #ff6b6b 0%, #ff4a47 100%)",
                "background:-webkit-linear-gradient(top,  #ff6b6b 0%,#ff4a47 100%)",
                "background:linear-gradient(to bottom,  #ff6b6b 0%,#ff4a47 100%)",
                "filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#ff6b6b', endColorstr='#ff4a47',GradientType=0 )"
            ],
            "cookieQuestionTriggerOnce": [
                "background:#ffffaf",
                "background:-moz-linear-gradient(top,  #ffffaf 0%, #ffff70 100%)",
                "background:-webkit-linear-gradient(top,  #ffffaf 0%,#ffff70 100%)",
                "background:linear-gradient(to bottom,  #ffffaf 0%,#ffff70 100%)",
                "filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#ffffaf', endColorstr='#ffff70',GradientType=0 )"
            ],
            "cookieQuestionTriggerYes": [
                "background:#b0e8b3",
                "background:-moz-linear-gradient(top,  #b0e8b3 0%, #88ea8e 100%)",
                "background:-webkit-linear-gradient(top,  #b0e8b3 0%,#88ea8e 100%)",
                "background:linear-gradient(to bottom,  #b0e8b3 0%,#88ea8e 100%)",
                "filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#b0e8b3', endColorstr='#88ea8e',GradientType=0 )"
            ]
        };
        this.styleRules = [
            ".cookieQuestionAnswer:focus {"
                +"border-style:ridge;"
                +"outline-color:white;"
                +"outline-offset:0;"
                +"outline-style:dotted;"
                +"outline-width:1px;"
            +"}",
            ".cookieQuestionAnswer:hover {"
                +"outline-style:none 0;"
                +"border-style:ridge;"
                +"font-weight:bold;"
            +"}",
            "#cookieQuestionTriggerNo_id:focus, #cookieQuestionTriggerNo_id:hover {"
                +"background:#ff4a47;"
                +"background:-moz-linear-gradient(top,  #ff4a47 0%, #ff6b6b 100%);"
                +"background:-webkit-linear-gradient(top,  #ff4a47 0%,#ff6b6b 100%);"
                +"background:linear-gradient(to bottom,  #ff4a47 0%,#ff6b6b 100%);"
                +"filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#ff4a47', endColorstr='#ff6b6b',GradientType=0 );"
            +"}",
            "#cookieQuestionTriggerOnce_id:focus, #cookieQuestionTriggerOnce_id:hover {"
                +"background:#ffff70;"
                +"background:-moz-linear-gradient(top,  #ffff70 0%, #ffffaf 100%);"
                +"background:-webkit-linear-gradient(top,  #ffff70 0%,#ffffaf 100%);"
                +"background:linear-gradient(to bottom,  #ffff70 0%,#ffffaf 100%);"
                +"filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#ffff70', endColorstr='#ffffaf',GradientType=0 );"
            +"}",
            "#cookieQuestionTriggerYes_id:focus, #cookieQuestionTriggerYes_id:hover {"
                +"background:#88ea8e;"
                +"background:-moz-linear-gradient(top,  #88ea8e 0%, #b0e8b3 100%);"
                +"background:-webkit-linear-gradient(top,  #88ea8e 0%,#b0e8b3 100%);"
                +"background:linear-gradient(to bottom,  #88ea8e 0%,#b0e8b3 100%);"
                +"filter:progid:DXImageTransform.Microsoft.gradient( startColorstr='#88ea8e', endColorstr='#b0e8b3',GradientType=0 );"
            +"}"
            ];
        this.langData = {
            "en": {
                "msg": [
                    "This website ist available for free.",
                    "Advertisement originated by Google (AdSense) is presented, cookies are used. ",
                    "Additionally this site uses own cookies which are only used to "
                        + "support functionality and are in no way used for your identification nor to track you. ",
                    "According to data protecting laws of the EU you need to accept the use of the mentioned cookies. ",
                    "Do you accept the use of cookies?"
                ],
                "no": "No",
                "once": "Once",
                "yes": "Yes"
            },
            "de": {
                "msg": [
                    "Diese Website ist kostenfrei verfügbar. ",
                    "Von Google bereit gestellte Werbung (AdSense) ist integriert "
                        + "und verwendet Cookies. ",
                    "Diese Site verwendet auch eigene Cookies, die "
                        + "weder zu Ihrer Identifikation noch zur Nachverfolgung, "
                        + "sondern zur Funktionalität dieser Site verwendet werden. ",
                    "Gemäß Datenschutzrichtlinie der EU müssen Sie der Verwendung "
                        + "der genannten Cookies zustimmen. ",
                    "Akzeptieren Sie die Verwendung von Cookies?"
                ],
                "no": "Nein",
                "once": "Einmalig",
                "yes": "Ja"
            }
        };
        this.lang = "en";
        this.rootLayer;
        this.styleSheet;
    }

    /**
     * Sets the language to use, defaults to "en".
     * 
     * @param {string} langCode The 2-letter lowercase language code like e.g. 
     * "en".
     * @returns {undefined}
     */
    setLang(langCode = "") {
        this.lang = this.langData[langCode] ? langCode : "en";
    }

    /**
     * Gets language specific versions of data, defaults to "en".
     * 
     * @param {} lang The 2-letter lowercase language code like e.g. 
     * "en".
     * @param {string} msgId The code for the data to return.
     * @returns {string} Language specifc data.
     */
    getLangMsg(lang, msgId) {
        var msg = "";
        if (this.langData[lang] && this.langData[lang][msgId]) {
            msg = this.langData[lang][msgId];
        }
        return msg;
    }

    /**
     * Gets language specific versions of data.
     * 
     * @param {string} msgId The code for the data to return.
     * @returns {string} Language specifc data.
     */
    getMsg(msgId) {
        var msg = this.getLangMsg(this.lang, msgId);
        if (!msg) {
            for (var l in this.langData) {
                if (this.langData[l].msgId) {
                    msg = this.langData[l].msgId;
                    break;
                }
            }
        }
        return msg;
    }

    /**
     * Displays the cookie question.
     * 
     * Relies on set this.bodyElem in super class CookieQuestionTheme
     * 
     * @returns {undefined}
     */
    displayQuestion() {
        
        this.styleSheet = CookieQuestionStyleElement.createStyleSheet(this.styleRules);
        
        this.rootLayer = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionForegroundLayer"], "div", "cookieQuestionForegroundLayer_id");
        var cookieMessageLayer = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionMessageLayer"], "div", "cookieQuestionMessageLayer_id");

        CookieQuestionStyleElement.appendText(this.getMsg("msg"), cookieMessageLayer);

        var cookieAnswerLayer = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionAnswerLayer"], "div", "cookieQuestionAnswerLayer_id");

        var cookieElemNo = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerNo"], "button", "cookieQuestionTriggerNo_id");
        CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerCommon"], cookieElemNo);
        CookieQuestionStyleElement.appendText([this.getMsg("no")], cookieElemNo);
        cookieElemNo.classList.add("cookieQuestionAnswer");
        cookieElemNo.classList.add("cookieQuestionNo");
        cookieElemNo.onclick = this.cookiesNo.bind(this);

        var cookieElemOnce = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerOnce"], "button", "cookieQuestionTriggerOnce_id");
        CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerCommon"], cookieElemOnce);
        CookieQuestionStyleElement.appendText([this.getMsg("once")], cookieElemOnce);
        cookieElemOnce.classList.add("cookieQuestionAnswer");
        cookieElemOnce.classList.add("cookieQuestionOnce");
        cookieElemOnce.onclick = this.cookiesOnce.bind(this);

        var cookieElemYes = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerYes"], "button", "cookieQuestionTriggerYes_id");
        CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerCommon"], cookieElemYes);
        CookieQuestionStyleElement.appendText([this.getMsg("yes")], cookieElemYes);
        cookieElemYes.classList.add("cookieQuestionAnswer");
        cookieElemYes.classList.add("cookieQuestionYes");
        cookieElemYes.onclick = this.cookiesYes.bind(this);
        
        cookieAnswerLayer.appendChild(cookieElemYes);
        cookieAnswerLayer.appendChild(cookieElemOnce);
        cookieAnswerLayer.appendChild(cookieElemNo);
        this.rootLayer.appendChild(cookieMessageLayer);
        this.rootLayer.appendChild(cookieAnswerLayer);
        var bodyChildNodes = this.bodyElem.childNodes;
        if (bodyChildNodes === null) {
            this.bodyElem.appendChild(this.rootLayer);
        }
        else {
            this.bodyElem.insertBefore(this.rootLayer, bodyChildNodes[0]);
        }
        cookieElemYes.focus();
    }

    /**
     * Removes the cookie question from screen.
     * 
     * Relies on set this.bodyElem in super class CookieQuestionTheme
     * 
     * @returns {undefined}
     */
    removeQuestion() {
        try {
            this.bodyElem.removeChild(this.rootLayer);
            this.rootLayer = null;
        }
        catch (err) {
        }
        CookieQuestionStyleElement.removeStyleSheet(this.styleSheet);
    }

    /**
     * Specifies the action to display a web page after cookies have been 
     * rejected (no).
     * 
     * @returns {undefined}
     */
    goNoCookieContent() {
        if (this.effectiveNoUrl()) {
            window.top.location.href = this.effectiveNoUrl();
        }
        else if (history.length > 1) {
            window.history.back();
        }
        else {
            window.top.location.href = "about:blank";
        }
    }

    /**
     * Specifies the action to display a web page after cookies have been 
     * accepted (once or yes).
     * 
     * @returns {undefined}
     */
    goContent() {
        if (this.effectiveYesUrl()) {
            window.top.location.href = this.effectiveYesUrl();
        }
        /* else stay on current page */
    }
}
