
"use strict";
//import * as  CookieQuestionCookieHelper from "CookieQuestionCookieHelper";

/*
 * @requires CookieQuestionCookieHelper.js
 * @version 1.0.0
 * 
 * MUST be instantied by a CookieQuestionTheme_[THEME-NAME] subclass.
 */

/**
 * Common functions used for all individual them(classe)s,
 * acts as a sort of interface to the CookieQuestion class.
 * 
 * @type type CookieQuestionTheme
 */
class CookieQuestionTheme {
    /**
     * 
     * @param {String} cookieQuestionDirUrlSlash An absolute or relative url
     * denoting the location of the cookieQuestion directory.
     * @param {String} overrideYesUrl Optional, the absolute or relative url of
     * the page to go to if cooke question was answered with yes, ignored if
     * empty.
     * @param {String} overrideNoUrl Optional, the absolute or relative url of
     * the page to go to if cooke question was answered with no, ignored if
     * empty.
     * @param {String} overrideCookieName Optional, the name of the cookie to
     * use, ignored if empty.
     * @returns {CookieQuestionTheme}
     */
    constructor(cookieQuestionDirUrlSlash = "", overrideYesUrl = "", overrideNoUrl = "", overrideCookieName = "") {
        // safe the cookieQuestionDirUrlS
        this.displayQuestion;
        this.removeQuestion;
        this.goContent;
        this.goNoCookieContent;
        this.setLang;
        this.yesCookieDays = 100;
        this.resourceDir = "themes/resources";
        this.resourcesUrlS = cookieQuestionDirUrlSlash.replace(/[^\w-.~:/+%]/g, "") + this.resourceDir + "/";
        this.overrideYesUrl = overrideYesUrl.replace(/[^\w-.~:/+%]/g, "");
        this.overrideNoUrl = overrideNoUrl.replace(/[^\w-.~:/+%]/g, "");
        this.yesMeansOnce = false;
        this.cookiesAccepted = false;
        var cookieNameTmp = overrideCookieName.replace(/('|")/g, "");
        this.cookieName = cookieNameTmp ? cookieNameTmp : "ContemporaryCodes.com_CookieQuestion";
        // Info (MDN):
        // defaults to the host portion of the current document
        // location (but not including subdomains) like e.g. "example.com"
        // If a domain is specified, subdomains are always included.
        // Cannot be used to overwrite false domain
        // empty string if default is wanted
        this.cookieDomainName = "";
        this.bodyElem;
    }

    /**
     * Sets the used functions.
     * This method must be called from constructor of subclass.
     * @param {function} displayQuestionFun
     * @param {function} removeQuestionFun
     * @param {function} goContentFun
     * @param {function} goNoCookieContentFun
     * @param {function} setLangFun
     * @returns {undefined}
     */
    setup(
        displayQuestionFun, removeQuestionFun,
        goContentFun, goNoCookieContentFun, setLangFun) {
        this.displayQuestion = displayQuestionFun;
        this.removeQuestion = removeQuestionFun;
        this.goContent = goContentFun;
        this.goNoCookieContent = goNoCookieContentFun;
        this.setLang = setLangFun;
    }

    /**
     * Gets the HTMLElement to be used as body, which may be the document oe a
     * frame. In such case the callback is only called if the document is ready.
     * @param {function} callback the function to call on exit.
     * @returns {HTMLElement} The body element or null.
     */
    getBodyElem(callback) {
        var bodyElem = null;
        try {
            bodyElem = document.getElementsByTagName("body")[0];
        }
        catch (e) {
        }

        if ((typeof (bodyElem) === "undefined") || (bodyElem === null)) {
            var cqFrame = document.getElementById("cookieQuestionFrame");
            if (cqFrame) {
                var bodyElemDoc = cqFrame.contentDocument;
                if (bodyElemDoc.readyState !== "complete") {
                    window.setTimeout(this.getBodyElem.bind(this), 100, callback);
                    return;
                }
                else {
                    bodyElem = bodyElemDoc.getElementsByTagName("body")[0];
                }
            }
        }
        callback(bodyElem);
    }

    /**
     * If a valid body element is given the browser's preferred language is
     * read and the display of the cookie question is triggered. Otherwise
     * the content page is displayed directly.
     * @param {HTMLElement} The body element to use.
     * @returns {undefined}
     */
    doShowCookieQuestion(bodyElem) {
        if ((typeof (bodyElem) === "undefined") || (bodyElem === null)) {
            window.setTimeout(this.goContent.bind(this), 100);
        }
        else {
            this.bodyElem = bodyElem;
            if (!(this.cookiesAccepted || this.queryCookiesAccepted())) {
                var langToUse = (navigator.languages ? navigator.languages[0] : (navigator.language || navigator.userLanguage));
                if ((typeof (langToUse) === "string") && (langToUse.length >= 2)) {
                    this.setLang(langToUse.substr(0, 2).toLowerCase());
                }
                this.displayQuestion();
            }
        }
    }

    /**
     * Initiates the detection of the body element and the display of the
     * cookieQuestion.
     * @returns {undefined}
     */
    showCookieQuestion() {
        window.setTimeout(this.getBodyElem.bind(this), 10, this.doShowCookieQuestion.bind(this));
    }

    /**
     * Queries if cookies have already been accepted, the acceptance flag is a
     * cookie itself.
     * 
     * @returns {Boolean}
     */
    queryCookiesAccepted() {
        var cookieVal = CookieQuestionCookieHelper.getCookieValue(this.cookieName);
        return (this.cookiesAccepted = (cookieVal === "1"));
    }

    /**
     * Specifies the action to take if cookies have been rejected (no).
     * @returns {undefined}
     */
    cookiesNo() {
        this.goNoCookieContent();
    }

    /**
     * Specifies the action to take if cookies have been accepted once.
     * @returns {undefined}
     */
    cookiesOnce() {
        if (CookieQuestionCookieHelper.setSessionCookieForDomain(this.cookieName, "1", this.cookieDomainName) === "1") {
            this.removeQuestion();
            this.goContent();
        }
    }

    /**
     * Specifies the action to take if cookies have been accepted (yes).
     * @returns {undefined}
     */
    cookiesYes() {
        if (this.yesMeansOnce) {
            this.cookiesOnce();
        }
        else {
            if (CookieQuestionCookieHelper.setCookieForDomain(this.cookieName, "1", this.yesCookieDays, this.cookieDomainName) === "1") {
                this.removeQuestion();
                this.goContent();
            }
        }
    }

    /**
     * The effective absolute or relative url to go to if cookie question was
     * answered yes, which is this.overrideYesUrl if not empty, subclass'
     * locationCookieContinue else.
     * @returns {CookieQuestionTheme.locationCookieContinue|String}
     */
    effectiveYesUrl() {
        return this.overrideYesUrl ? this.overrideYesUrl : this.locationCookieContinue;
    }

    /**
     * The effective absolute or relative url to go to if cookie question was
     * answered no, which is this.overrideNoUrl if not empty, subclass'
     * locationNoCookies else.
     * @returns {CookieQuestionTheme.locationNoCookies|String}
     */
    effectiveNoUrl() {
        return this.overrideNoUrl ? this.overrideNoUrl : this.locationNoCookies;
    }
}
