
"use strict";
//import * as CookieQuestionStyleElement from "CookieQuestionStyleElement";

/**
 * @requires CookieQuestionStyleElement.js
 * @version 1.0.0
 */

/**
 * Theme-individual data and functions.
 * 
 * @type CookieQuestionTheme_Massive
 */
class CookieQuestionTheme_Massive extends CookieQuestionTheme {
    constructor(cookieQuestionDirUrlS, overrideYesUrl = "", overrideNoUrl = "", overrideCookieName = "") {
        super(cookieQuestionDirUrlS, overrideYesUrl, overrideNoUrl, overrideCookieName);
        this.setup(this.displayQuestion.bind(this),
            this.removeQuestion.bind(this),
            this.goContent.bind(this),
            this.goNoCookieContent.bind(this),
            this.setLang.bind(this));
        // empty if cookie question is on content page
        this.locationCookieContinue = "";
        // empty to go history back or about_blank
        this.locationNoCookies = "";
        this.css = {
            "cookieQuestionBackgroundLayer": [
                "background-color:rgba(128,128,128,0.9)",
                "border:0",
                "box-sizing:border-box",
                "height:100%",
                "left:0",
                "margin:0",
                "padding:0",
                "position:fixed",
                "top:0",
                "width:100%",
                "z-index:99999"
            ],
            "cookieQuestionForegroundLayer": [
                "-moz-border-radius:15px",
                "-moz-box-shadow:#06083B 8px 8px 8px",
                "-webkit-border-radius:15px",
                "-webkit-box-shadow:#06083B 8px 8px 8px",
                "background-color:#E3E3D1",
                "border-radius:15px",
                "border:3px solid #220AC2",
                "box-shadow:#06083B 8px 8px 8px",
                "box-sizing:border-box",
                "height:500px",
                "left:50%",
                "margin:-250px 0 0 -250px",
                "padding:1em;",
                "position:fixed",
                "top:50%",
                "width:500px"
            ],
            "cookieQuestionMessageLayer": [
                "background:transparent;",
                "border:0 none",
                "box-sizing:border-box",
                "color:#337",
                "font-size:1em",
                "font-weight:bolder",
                "height:395px",
                "line-height:1.5em",
                "margin:5px auto",
                "overflow-style:marquee",
                "overflow-wrap:break-word",
                "overflow-x:hidden",
                "overflow-y:auto",
                "padding:0.5em 1em",
                "text-align:center",
                "width:100%",
                "word-break:keep-all",
                "word-wrap:normal"
            ],
            "cookieQuestionTriggerCommon": [
                "background:transparent",
                "border:0 none",
                "bottom:10px",
                "cursor:pointer",
                "display:block",
                "padding:0",
                "position:absolute"
            ],
            "cookieQuestionTriggerNo": [
                "left:125px",
                "margin:0 0 0 -81px",
            ],
            "cookieQuestionTriggerOnce": [
                "left:250px",
                "margin:0 0 0 -61px",
            ],
            "cookieQuestionTriggerYes": [
                "left:375px",
                "margin:0 0 0 -41px",
            ]
        };
        this.langData = {
            "en": {
                "msg": [
                    "This website ist available for free.",
                    "",
                    "",
                    "Advertisement originated by Google (AdSense) is presented, "
                        + "cookies are used.",
                    "",
                    "",
                    "Additionally this site uses own cookies which are only used to "
                        + "support functionality and are in no way used for your identification.",
                    "",
                    "",
                    "According to data protecting laws of the EU you need to accept the use of the mentioned cookies.",
                    "",
                    "",
                    "Do you accept the use of cookies?"
                ],
                "no": "No",
                "once": "Once",
                "yes": "Yes",
                "buttonNoName": "buttonNoRedBgE3E3D1_122x48.png",
                "buttonOnceName": "buttonOnceYellowBgE3E3D1_122x48.png",
                "buttonYesName": "buttonYesGreenBgE3E3D1_122x48.png"
            },
            "de": {
                "msg": [
                    "Diese Website ist kostenfrei verfügbar.",
                    "",
                    "",
                    "Von Google bereit gestellte Werbung (AdSense) ist integriert "
                        + "und verwendet Cookies.",
                    "",
                    "",
                    "Diese Site verwendet auch eigene Cookies, die "
                        + "nicht zu Ihrer Identifikation, "
                        + "sondern zur Funktionalität dieser Site verwendet werden.",
                    "",
                    "",
                    "Gemäß Datenschutzrichtlinie der EU müssen Sie der Verwendung "
                        + "der genannten Cookies zustimmen.",
                    "",
                    "",
                    "Akzeptieren Sie die Verwendung von Cookies?"
                ],
                "no": "Nein",
                "once": "Einmalig",
                "yes": "Ja",
                "buttonNoName": "buttonNeinRedBgE3E3D1_122x48.png",
                "buttonOnceName": "buttonEinmaligYellowBgE3E3D1_122x48.png",
                "buttonYesName": "buttonJaGreenBgE3E3D1_122x48.png"
            }
        };
        this.lang = "en";
        this.rootLayer;
    }

    /**
     * Sets the language to use, defaults to "en".
     * 
     * @param {string} langCode The 2-letter lowercase language code like e.g. 
     * "en".
     * @returns {undefined}
     */
    setLang(langCode = "") {
        this.lang = this.langData[langCode] ? langCode : "en";
    }

    /**
     * Gets language specific versions of data, defaults to "en".
     * 
     * @param {} lang The 2-letter lowercase language code like e.g. 
     * "en".
     * @param {string} msgId The code for the data to return.
     * @returns {string} Language specifc data.
     */
    getLangMsg(lang, msgId) {
        var msg = "";
        if (this.langData[lang] && this.langData[lang][msgId]) {
            msg = this.langData[lang][msgId];
        }
        return msg;
    }

    /**
     * Gets language specific versions of data.
     * 
     * @param {string} msgId The code for the data to return.
     * @returns {string} Language specifc data.
     */
    getMsg(msgId) {
        var msg = this.getLangMsg(this.lang, msgId);
        if (!msg) {
            for (var l in this.langData) {
                if (this.langData[l].msgId) {
                    msg = this.langData[l].msgId;
                    break;
                }
            }
        }
        return msg;
    }

    /**
     * Displays the cookie question.
     * 
     * Relies on set this.bodyElem in super class CookieQuestionTheme
     * 
     * @returns {undefined}
     */
    displayQuestion() {
                
        this.rootLayer = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionBackgroundLayer"], "div", "cookieQuestionBackgroundLayer_id");
        var cookieForegroundLayer = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionForegroundLayer"], "div", "cookieQuestionForegroundLayer_id");
        var cookieMessageLayer = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionMessageLayer"], "div", "cookieQuestionMessageLayer_id");

        CookieQuestionStyleElement.appendText(this.getMsg("msg"), cookieMessageLayer);

        var cookieElemNo = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerNo"], "img", "cookieQuestionTriggerNo_id");
        CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerCommon"], cookieElemNo);
        cookieElemNo.alt = this.getMsg("no");
        cookieElemNo.src = this.resourcesUrlS + this.getMsg("buttonNoName");
        cookieElemNo.onclick = this.cookiesNo.bind(this);

        var cookieElemOnce = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerOnce"], "img", "cookieQuestionTriggerOnce_id");
        CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerCommon"], cookieElemOnce);
        cookieElemOnce.alt = this.getMsg("once");
        cookieElemOnce.src = this.resourcesUrlS + this.getMsg("buttonOnceName");
        cookieElemOnce.onclick = this.cookiesOnce.bind(this);

        var cookieElemYes = CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerYes"], "img", "cookieQuestionTriggerYes_id");
        CookieQuestionStyleElement.applyCss(this.css["cookieQuestionTriggerCommon"], cookieElemYes);
        cookieElemYes.alt = this.getMsg("yes");
        cookieElemYes.src = this.resourcesUrlS + this.getMsg("buttonYesName");
        cookieElemYes.onclick = this.cookiesYes.bind(this);

        this.rootLayer.appendChild(cookieForegroundLayer);
        cookieForegroundLayer.appendChild(cookieElemYes);
        cookieForegroundLayer.insertBefore(cookieElemOnce, cookieElemYes);
        cookieForegroundLayer.insertBefore(cookieElemNo, cookieElemOnce);
        cookieForegroundLayer.insertBefore(cookieMessageLayer, cookieElemNo);
        var bodyChildNodes = this.bodyElem.childNodes;
        if (bodyChildNodes === null) {
            this.bodyElem.appendChild(this.rootLayer);
        }
        else {
            this.bodyElem.insertBefore(this.rootLayer, bodyChildNodes[0]);
        }
    }

    /**
     * Removes the cookie question from screen.
     * 
     * Relies on set this.bodyElem in super class CookieQuestionTheme
     * 
     * @returns {undefined}
     */
    removeQuestion() {
        try {
            this.bodyElem.removeChild(this.rootLayer);
            this.rootLayer = null;
        }
        catch (err) {
        }
    }

    /**
     * Specifies the action to display a web page after cookies have been 
     * rejected (no).
     * 
     * @returns {undefined}
     */
    goNoCookieContent() {
        if (this.effectiveNoUrl()) {
            window.top.location.href = this.effectiveNoUrl();
        }
        else if (history.length > 1) {
            window.history.back();
        }
        else {
            window.top.location.href = "about:blank";
        }
    }

    /**
     * Specifies the action to display a web page after cookies have been 
     * accepted (once or yes).
     * 
     * @returns {undefined}
     */
    goContent() {
        if (this.effectiveYesUrl()) {
            window.top.location.href = this.effectiveYesUrl();
        }
        /* else stay on current page */
    }
}
